@@ -21,10 +21,10 @@ class Index
      * å
      *
      * @access public
-     * @param object ꥯȥ֥
      * @param object ǡ֥
+     * @param object ƥȴ֥
      */
-    function execute(&$request, &$dm)
+    function execute(&$data, &$context)
     {
         $this->start_string = 'Hello SyL!';
     }
