@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerFile.php,v 1.13 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerFile.php,v 1.14 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_File.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerFile.php,v 1.13 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerFile.php,v 1.14 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_LoggerFile extends SyL_Logger
@@ -54,7 +54,7 @@ class SyL_LoggerFile extends SyL_Logger
      * 
      * @access public
      */
-    var $writer = null;
+    var $appender = null;
 
     /**
      * ץ
@@ -69,9 +69,9 @@ class SyL_LoggerFile extends SyL_Logger
         $filename = str_replace('MM',   date('m'), $filename);
         $filename = str_replace('DD',   date('d'), $filename);
 
-        if ($this->writer == null) {
-            $this->writer =& SyL_File::getObject('writer', $filename);
-            $this->writer->open('ab');
+        if ($this->appender == null) {
+            $this->appender =& SyL_File::factory('a', $filename);
+            $this->appender->open();
         }
     }
 
@@ -88,7 +88,7 @@ class SyL_LoggerFile extends SyL_Logger
             $message = sprintf('%s [%s] [%s] %s "%s %s" %s', date($this->datetime_format), SYL_ENV_TYPE, $level, $this->remote_addr, $this->request_method, $this->request_uri, rtrim($message));
         }
         if ($this->immediate || ($level == '')) {
-            $this->writer->write($message . $this->eof);
+            $this->appender->write($message . $this->eol);
         } else {
             $this->buffer[] = $message;
         }
@@ -101,10 +101,10 @@ class SyL_LoggerFile extends SyL_Logger
      */
     function close()
     {
-        if ($this->writer != null) {
+        if ($this->appender != null) {
             parent::close();
-            $this->writer->close();
-            $this->writer = null;
+            $this->appender->close();
+            $this->appender = null;
         }
     }
 }
