@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestSession.php,v 1.10 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestSession.php,v 1.11 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestSession.php,v 1.10 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestSession.php,v 1.11 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestSession extends SyL_UtilProperty
@@ -82,9 +82,7 @@ class SyL_RequestSession extends SyL_UtilProperty
             $session_secure = (bool)$session_secure;
             session_set_cookie_params(0, $this->path, $session_domain, $session_secure);
             // å¸ѥ
-            if (SYL_SESSION_SAVE_PATH) {
-                session_save_path(SYL_SESSION_SAVE_PATH);
-            }
+            $this->setSavePath();
 
             // å󳫻
             $this->startSession();
@@ -95,6 +93,18 @@ class SyL_RequestSession extends SyL_UtilProperty
         }
     }
 
+    /**
+     * å¸ѥ
+     *
+     * @access protected
+     */
+    function setSavePath()
+    {
+        if (SYL_SESSION_SAVE_PATH) {
+            session_save_path(SYL_SESSION_SAVE_PATH);
+        }
+    }
+
     /**
      * å򳫻Ϥ
      *
