@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.15 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,34 +35,11 @@
 /**
  * PATH_INFOĶѿե졼ͤ륯饹
  *
- * +++ 
- * ե̾
- * 󥯥饹̾
- * ̾
- * ƥץ졼ȥե̾
- *
- * +++ 
- *   /dir/app1.php/hoge1/hoge2/cmd.test.html
- * 
- * [ե̾]
- *   /hoge1/hoge2/test.php
- *   1) .../app1.php/test2_2/test.html => /test2_2/test.php
- *   2) .../app1.php/test.html => /test.php
- *   3) .../app1.php/ => /ʥǥեȥ̾
- * [󥯥饹̾]
- *   Hoge1_Hoge2_Test
- * [̾]
- *   cmd
- *   1) .../app1.php/test2_2/test.html => ̵
- *   2) .../app1.php/ => ̵
- * [ƥץ졼ȥե̾]
- *   /hoge1/hoge2/test.html
- *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.15 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo extends SyL_Router
@@ -81,16 +58,11 @@ class SyL_RouterPathinfo extends SyL_Router
      * @access protected
      * @param object ꥯȥ֥
      */
-    function createProperty(&$data)
+    function createActionInfo(&$data)
     {
         // PATH_INFOĶѿ
         $pathinfo = isset($_SERVER['PATH_INFO']) ? $_SERVER['PATH_INFO'] : '';
 
-        // ѥå
-        if ($this->isInvalidPath($pathinfo)) {
-            SyL_Response::redirect404();
-        }
-
         if ($pathinfo == '') {
             $this->action_name = '';
             $this->action_file = '/' . $this->action_file_default;
@@ -99,7 +71,7 @@ class SyL_RouterPathinfo extends SyL_Router
             $this->action_file = $pathinfo . $this->action_file_default;
         } else {
             // ĥȽ
-            if ($this->ext && !preg_match('/^(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo)) {
+            if ($this->url_ext && !preg_match('/^(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo)) {
                 SyL_Response::redirect404();
             }
             $pathinfo_file  = basename($pathinfo);
@@ -142,38 +114,46 @@ class SyL_RouterPathinfo extends SyL_Router
             }
         }
 
+        $action_name = null;
+        // ͤѥ᡼Υ
+        if (($action_name === null) && ((SYL_ROUTER_EXTRA_ACTION == '1') || (SYL_ROUTER_EXTRA_ACTION == '3'))) {
+            $reg = '/^' . preg_quote(SYL_ACTION_KEY) . '_(.+)(_x|_y)?$/';
+            foreach ($data->gets() as $name => $value) {
+                if (preg_match($reg, $name, $matches)) {
+                    $action_name = $matches[1];
+                    break;
+                }
+            }
+        }
+        // ͤѥ᡼ͤ
+        if (($action_name === null) && ((SYL_ROUTER_EXTRA_ACTION == '2') || (SYL_ROUTER_EXTRA_ACTION == '3'))) {
+            $action_name = $data->get(SYL_ACTION_KEY);
+        }
         // ֤
-        $action_name = $data->get(SYL_ACTION_KEY);
         if ($action_name !== null) {
             $this->action_name = $action_name;
         }
 
         // PATH_INFO
-        $this->pathinfo = explode('/', $pathinfo);
-        array_shift($this->pathinfo);
-        if (count($this->pathinfo) > 0) {
-            array_pop($this->pathinfo);
+        $pathinfo = explode('/', $pathinfo);
+        array_shift($pathinfo);
+        if (count($pathinfo) > 0) {
+            array_pop($pathinfo);
         }
 
         // 饹ե
-        if ($this->action_file != '') {
-            $classname = implode('_', array_map('ucfirst', $this->pathinfo));
-            if ($classname != '') {
-                $this->class_name = $classname . '_' . ucfirst(basename($this->action_file, $this->exe_ext));
-            } else {
-                $this->class_name = ucfirst(basename($this->action_file, $this->exe_ext));
-            }
+        $classname = implode('_', array_map('ucfirst', $pathinfo));
+        if ($classname != '') {
+            $this->action_class = $classname . '_' . ucfirst(basename($this->action_file, $this->exe_ext));
+        } else {
+            $this->action_class = ucfirst(basename($this->action_file, $this->exe_ext));
         }
 
 /*
 echo "pathinfo: " . $pathinfo . "<br>";
 echo "action_name: " . $this->action_name . "<br>";
 echo "action_file: " . $this->action_file . "<br>";
-echo "class_name: " . $this->class_name . "<br>";
-echo "syl_self: " . $this->syl_self . "<br>";
-echo "<pre>";
-print_r($this->pathinfo);
-echo "</pre>";
+echo "class_name: " . $this->action_class . "<br>";
 exit;
 */
 
