@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.14 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.15 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.14 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.15 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
@@ -106,7 +106,7 @@ class SyL_Router
      * @param string ܾ󥪥֥̾
      * @return object ܾ󥪥֥
      */
-    function &getObject(&$data, $rule)
+    function &factory(&$data, $rule)
     {
         $classname = 'SyL_Router' . ucfirst($rule);
         include_once SYL_INCLUDE_DIR . "/framework/Router/{$classname}.php";
