@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilInfo.php,v 1.4 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilInfo.php,v 1.5 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilInfo.php,v 1.4 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilInfo.php,v 1.5 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_UtilInfo
@@ -301,6 +301,8 @@ if (!$display || in_array('CONSTANT', $display)) {
         $type = 'DIR';
     } else if (preg_match('/^SYL_AUTH_/', $name)) {
         $type = 'AUTH';
+    } else if (preg_match('/^SYL_COOKIE_/', $name)) {
+        $type = 'COOKIE';
     } else if (preg_match('/^SYL_ENCODE_/', $name)) {
         $type = 'ENCODE';
     } else if (preg_match('/^SYL_ERROR/', $name)) {
