@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.7 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.8 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_SMARTY_DIR . 'Smarty.class.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.7 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.8 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayoutSmarty extends SyL_ViewLayout
@@ -69,14 +69,11 @@ class SyL_ViewLayoutSmarty extends SyL_ViewLayout
     {
         parent::SyL_ViewLayout($context, $data);
 
-        $compile_dir = SYL_SMARTY_COMPILE_DIR . basename(SYL_APP_DIR);
-        if (!is_dir($compile_dir)) {
-            trigger_error("[SyL error] Smarty compile_dir not found ({$compile_dir})", E_USER_ERROR);
-        }
         $this->smarty =& new Smarty();
-        $this->smarty->compile_dir = $compile_dir;
+        $this->smarty->compile_dir = SYL_SMARTY_COMPILE_DIR;
         $this->smarty->config_dir  = SYL_SMARTY_CONFIG_DIR;
         $this->smarty->cache_dir   = SYL_SMARTY_CACHE_DIR;
+        $this->smarty->compile_id  = basename(SYL_APP_DIR);
     }
 
     /**
