@@ -17,10 +17,10 @@ class {SYL_CLASS}
      * å
      *
      * @access public
-     * @param object ꥯȥ֥
      * @param object ǡ֥
+     * @param object ƥȴ֥
      */
-    function execute(&$request, &$context)
+    function execute(&$data, &$context)
     {
     }
 
